@@ -9,6 +9,7 @@ use crate::{
 };
 use log::*;
 use solana_runtime::{
+    accounts_update_notifier_interface::AccountsUpdateNotifier,
     bank_forks::{ArchiveFormat, BankForks, SnapshotConfig},
     snapshot_utils,
 };
@@ -33,6 +34,7 @@ fn to_loadresult(
 ///
 /// If a snapshot config is given, and a snapshot is found, it will be loaded.  Otherwise, load
 /// from genesis.
+#[allow(clippy::too_many_arguments)]
 pub fn load(
     genesis_config: &GenesisConfig,
     blockstore: &Blockstore,
@@ -42,6 +44,7 @@ pub fn load(
     process_options: ProcessOptions,
     transaction_status_sender: Option<&TransactionStatusSender>,
     cache_block_meta_sender: Option<&CacheBlockMetaSender>,
+    accounts_update_notifier: Option<AccountsUpdateNotifier>,
 ) -> LoadResult {
     if let Some(snapshot_config) = snapshot_config.as_ref() {
         info!(
@@ -70,6 +73,7 @@ pub fn load(
                 archive_slot,
                 archive_hash,
                 archive_format,
+                accounts_update_notifier,
             );
         } else {
             info!("No snapshot package available; will load from genesis");
@@ -84,6 +88,7 @@ pub fn load(
         account_paths,
         process_options,
         cache_block_meta_sender,
+        accounts_update_notifier,
     )
 }
 
@@ -93,6 +98,7 @@ fn load_from_genesis(
     account_paths: Vec<PathBuf>,
     process_options: ProcessOptions,
     cache_block_meta_sender: Option<&CacheBlockMetaSender>,
+    accounts_update_notifier: Option<AccountsUpdateNotifier>,
 ) -> LoadResult {
     info!("Processing ledger from genesis");
     to_loadresult(
@@ -102,6 +108,7 @@ fn load_from_genesis(
             account_paths,
             process_options,
             cache_block_meta_sender,
+            accounts_update_notifier,
         ),
         None,
     )
@@ -121,6 +128,7 @@ fn load_from_snapshot(
     archive_slot: Slot,
     archive_hash: Hash,
     archive_format: ArchiveFormat,
+    accounts_update_notifier: Option<AccountsUpdateNotifier>,
 ) -> LoadResult {
     info!("Loading snapshot package: {:?}", archive_filename);
 
@@ -145,6 +153,7 @@ fn load_from_snapshot(
         process_options.shrink_ratio,
         process_options.accounts_db_test_hash_calculation,
         process_options.accounts_db_skip_shrink,
+        accounts_update_notifier,
     )
     .expect("Load from snapshot failed");
     if let Some(shrink_paths) = shrink_paths {
